==> fifechan_0.1.4.orig.tar.gz: fifechan-0.1.4/README.md <==
![FIFEGUI LOGO](https://raw.githubusercontent.com/fifengine/fifechan/master/docs/logo/FIFEgui_small_c3.png)

## FIFECHAN

| [Website](http://fifengine.net/) | [Forum](http://forums.fifengine.net/) | [![#fife on Freenode](https://img.shields.io/badge/freenode-%23fife-green.svg)](https://webchat.freenode.net/?channels=fife) | [Changelog](https://github.com/fifengine/fifechan/blob/master/CHANGELOG.md) | [Releases](https://github.com/fifengine/fifechan/releases) | [Source Code (zip)](https://github.com/fifengine/fifechan/archive/master.zip) |
|:--------:|:--------:|:--------:|:--------:|:--------:|:--------:|:--------:|

| Continuous Integration | Linux |   Mac    | Windows |
|:----------------------:|:-----:|:--------:|:-------:|
| **Build Status** | [![Travis Build Status](https://travis-ci.org/fifengine/fifechan.svg?branch=master)](https://travis-ci.org/fifengine/fifechan) | [![Travis Build Status](https://travis-ci.org/fifengine/fifechan.svg?branch=master)](https://travis-ci.org/fifengine/fifechan) | [![Appveyor Build status](https://ci.appveyor.com/api/projects/status/github/fifengine/fifechan?branch=master&svg=true)](https://ci.appveyor.com/project/LinuxDonald/fifechan) | 
| **Development Releases**  |   -    |    -     | [All artifacts](https://ci.appveyor.com/project/LinuxDonald/fifechan/build/artifacts) <br> [fifechan-shared-VC14.zip](https://ci.appveyor.com/api/projects/LinuxDonald/fifechan/artifacts/fifechan-shared-VC14.zip) <br> [fifechan-static-VC14.zip](https://ci.appveyor.com/api/projects/LinuxDonald/fifechan/artifacts/fifechan-static-VC14.zip) |


## Introduction to Fifechan

Fifechan is a lightweight cross platform GUI library written in C++ specifically
designed for games. It has a small yet powerful built in set of extendable GUI 
Widgets allowing users to create virtually unlimited types of widgets. 

Fifechan supports rendering in SDL, OpenGL, or Allegro out of the box or it can be 
adapted to use any rendering engine the user requires. Events are pushed to 
Fifechan which allows users to use any input library they wish or they could use
the built in input handling through either SDL input or Allegro input. 

The primary goal for Fifechan is to keep it extendable, lightweight and still be 
powerful enough to use in all types of games out of the box. 

## Downloads

#### Latest Releases

You find the latest releases on [Github Releases](https://github.com/fifengine/fifechan/releases).

#### Development Releases

We also provide releases for the latest successful build. You find them listed in the Continous Integration table above.

## Getting involved

If you want to get involved with the development, come join our IRC channel #fife on Freenode.
Feel free to drop us a line there and we'll help you getting started!

==> fifechan_0.1.5.orig.tar.gz: fifechan-0.1.5/README.md <==
![FIFEGUI LOGO](https://raw.githubusercontent.com/fifengine/fifechan/master/docs/logo/FIFEgui_small_c3.png)

## FIFECHAN

| [Website](http://fifengine.net/) | [![#fife on Freenode](https://img.shields.io/badge/freenode-%23fife-green.svg)](https://webchat.freenode.net/?channels=fife) | [Changelog](https://github.com/fifengine/fifechan/blob/master/CHANGELOG.md) | [Releases](https://github.com/fifengine/fifechan/releases) | [Source Code (zip)](https://github.com/fifengine/fifechan/archive/master.zip) |
|:--------:|:--------:|:--------:|:--------:|:--------:|

| Continuous Integration | Linux |   Mac    | Windows |
|:----------------------:|:-----:|:--------:|:-------:|
| **Build Status** | [![Travis Build Status](https://travis-ci.org/fifengine/fifechan.svg?branch=master)](https://travis-ci.org/fifengine/fifechan) | [![Travis Build Status](https://travis-ci.org/fifengine/fifechan.svg?branch=master)](https://travis-ci.org/fifengine/fifechan) | [![Appveyor Build status](https://ci.appveyor.com/api/projects/status/github/fifengine/fifechan?branch=master&svg=true)](https://ci.appveyor.com/project/LinuxDonald/fifechan) | 
| **Development Releases**  |   -    |    -     | [All artifacts](https://ci.appveyor.com/project/LinuxDonald/fifechan/build/artifacts) <br> [fifechan-shared-VC15-x86.zip](https://ci.appveyor.com/api/projects/LinuxDonald/fifechan/artifacts/fifechan-shared-VC15-x86.zip) <br> [fifechan-static-VC15-x86.zip](https://ci.appveyor.com/api/projects/LinuxDonald/fifechan/artifacts/fifechan-static-VC15-x86.zip) |

Fifechan is also already available from the following package repositories:

[![Packaging status](https://repology.org/badge/vertical-allrepos/fifechan.svg)](https://repology.org/metapackage/fifechan)

## Introduction to Fifechan

Fifechan is a lightweight cross platform GUI library written in C++ specifically
designed for games. It has a small yet powerful built in set of extendable GUI 
Widgets allowing users to create virtually unlimited types of widgets. 

Fifechan supports rendering in SDL, OpenGL, or Allegro out of the box or it can be 
adapted to use any rendering engine the user requires. Events are pushed to 
Fifechan which allows users to use any input library they wish or they could use
the built in input handling through either SDL input or Allegro input. 

The primary goal for Fifechan is to keep it extendable, lightweight and still be 
powerful enough to use in all types of games out of the box. 

## Downloads

#### Latest Releases

You find the latest releases on [Github Releases](https://github.com/fifengine/fifechan/releases).

#### Development Releases

We also provide releases for the latest successful build. You find them listed in the Continous Integration table above.

## Getting involved

If you want to get involved with the development, come join our IRC channel #fife on Freenode.
Feel free to drop us a line there and we'll help you getting started!
